@@ -32,9 +32,11 @@ class ArtstationExtractor(Extractor):
         data = self.metadata()
 
         for project in self.projects():
-            for asset in self.get_project_assets(project["hash_id"]):
+            for num, asset in enumerate(
+                    self.get_project_assets(project["hash_id"]), 1):
                 asset.update(data)
                 adict = asset["asset"]
+                asset["num"] = num
                 yield Message.Directory, asset
 
                 if adict["has_embedded_player"] and self.external:
@@ -85,6 +87,7 @@ class ArtstationExtractor(Extractor):
         assets = data["assets"]
         del data["assets"]
 
+        data["count"] = len(assets)
         if len(assets) == 1:
             data["asset"] = assets[0]
             yield data
@@ -100,16 +103,23 @@ class ArtstationExtractor(Extractor):
         return response.json()
 
     def _pagination(self, url, params=None, json=None):
+        headers = {
+            "Accept" : "application/json, text/plain, */*",
+            "Origin" : self.root,
+            "Referer": self.root + "/",
+        }
+
         if json:
             params = json
-            kwargs = {"json": json}
+            headers["PUBLIC-CSRF-TOKEN"] = self._init_csrf_token()
+            kwargs = {"method": "POST", "headers": headers, "json": json}
         else:
             if not params:
                 params = {}
-            kwargs = {"params": params}
+            kwargs = {"params": params, "headers": headers}
 
-        params["page"] = 1
         total = 0
+        params["page"] = 1
 
         while True:
             data = self.request(url, **kwargs).json()
@@ -121,6 +131,17 @@ class ArtstationExtractor(Extractor):
 
             params["page"] += 1
 
+    def _init_csrf_token(self):
+        url = self.root + "/api/v2/csrf_protection/token.json"
+        headers = {
+            "Accept" : "*/*",
+            "Origin" : self.root,
+            "Referer": self.root + "/",
+        }
+        return self.request(
+            url, method="POST", headers=headers, json={},
+        ).json()["public_csrf_token"]
+
     @staticmethod
     def _no_cache(url, alphabet=(string.digits + string.ascii_letters)):
         """Cause a cache miss to prevent Cloudflare 'optimizations'
@@ -295,34 +316,46 @@ class ArtstationSearchExtractor(ArtstationExtractor):
     archive_fmt = "s_{search[query]}_{asset[id]}"
     pattern = (r"(?:https?://)?(?:\w+\.)?artstation\.com"
                r"/search/?\?([^#]+)")
-    test = ("https://www.artstation.com/search?q=ancient&sort_by=rank", {
+    test = ("https://www.artstation.com/search?query=ancient&sort_by=rank", {
         "range": "1-20",
         "count": 20,
     })
 
     def __init__(self, match):
         ArtstationExtractor.__init__(self, match)
-        query = text.parse_query(match.group(1))
-        self.query = query.get("q", "")
-        self.sorting = query.get("sort_by", "rank").lower()
+        self.params = query = text.parse_query(match.group(1))
+        self.query = text.unquote(query.get("query") or query.get("q", ""))
+        self.sorting = query.get("sort_by", "relevance").lower()
+        self.tags = query.get("tags", "").split(",")
 
     def metadata(self):
         return {"search": {
             "query"  : self.query,
             "sorting": self.sorting,
+            "tags"   : self.tags,
         }}
 
     def projects(self):
+        filters = []
+        for key, value in self.params.items():
+            if key.endswith("_ids") or key == "tags":
+                filters.append({
+                    "field" : key,
+                    "method": "include",
+                    "value" : value.split(","),
+                })
+
         url = "{}/api/v2/search/projects.json".format(self.root)
-        return self._pagination(url, json={
-            "additional_fields": "[]",
-            "filters"          : "[]",
-            "page"             : None,
-            "per_page"         : "50",
-            "pro_first"        : "1",
+        data = {
             "query"            : self.query,
+            "page"             : None,
+            "per_page"         : 50,
             "sorting"          : self.sorting,
-        })
+            "pro_first"        : "1",
+            "filters"          : filters,
+            "additional_fields": (),
+        }
+        return self._pagination(url, json=data)
 
 
 class ArtstationArtworkExtractor(ArtstationExtractor):
