@@ -31,6 +31,8 @@ class MastodonExtractor(BaseExtractor):
     def items(self):
         for status in self.statuses():
 
+            if self._check_move:
+                self._check_move(status["account"])
             if not self.reblogs and status["reblog"]:
                 self.log.debug("Skipping %s (reblog)", status["id"])
                 continue
@@ -56,6 +58,12 @@ class MastodonExtractor(BaseExtractor):
         """Return an iterable containing all relevant Status objects"""
         return ()
 
+    def _check_move(self, account):
+        self._check_move = None
+        if "moved" in account:
+            self.log.warning("Account '%s' moved to '%s'",
+                             account["acct"], account["moved"]["acct"])
+
 
 INSTANCES = {
     "mastodon.social": {
@@ -179,12 +187,11 @@ class MastodonAPI():
             try:
                 access_token = INSTANCES[extractor.category]["access-token"]
             except (KeyError, TypeError):
-                raise exception.StopExtraction(
-                    "Missing access token.\n"
-                    "Run 'gallery-dl oauth:mastodon:%s' to obtain one.",
-                    extractor.instance)
-
-        self.headers = {"Authorization": "Bearer " + access_token}
+                pass
+        if access_token:
+            self.headers = {"Authorization": "Bearer " + access_token}
+        else:
+            self.headers = None
 
     def account_id_by_username(self, username):
         if username.startswith("id:"):
@@ -193,6 +200,7 @@ class MastodonAPI():
         handle = "@{}@{}".format(username, self.extractor.instance)
         for account in self.account_search(handle, 1):
             if account["username"] == username:
+                self.extractor._check_move(account)
                 return account["id"]
         raise exception.NotFoundError("account")
 
@@ -232,6 +240,11 @@ class MastodonAPI():
 
             if code < 400:
                 return response
+            if code == 401:
+                raise exception.StopExtraction(
+                    "Invalid or missing access token.\n"
+                    "Run 'gallery-dl oauth:mastodon:%s' to obtain one.",
+                    self.extractor.instance)
             if code == 404:
                 raise exception.NotFoundError()
             if code == 429:
