@@ -116,13 +116,17 @@ class TumblrExtractor(Extractor):
 
                     if self.original and "/s2048x3072/" in photo["url"] and (
                             photo["width"] == 2048 or photo["height"] == 3072):
-                        photo["url"] = self._original_photo(photo["url"])
+                        photo["url"], fb = self._original_photo(photo["url"])
+                        if fb:
+                            post["_fallback"] = self._original_image_fallback(
+                                photo["url"], post["id"])
 
                     del photo["original_size"]
                     del photo["alt_sizes"]
                     posts.append(
                         self._prepare_image(photo["url"], post.copy()))
                     del post["photo"]
+                    post.pop("_fallback", None)
 
             url = post.get("audio_url")  # type "audio"
             if url and url.startswith("https://a.tumblr.com/"):
@@ -138,8 +142,12 @@ class TumblrExtractor(Extractor):
                 # API response, but they can't contain images/videos anyway
                 body = post["reblog"]["comment"] + post["reblog"]["tree_html"]
                 for url in _findall_image(body):
-                    url = self._original_inline_image(url)
+                    url, fb = self._original_inline_image(url)
+                    if fb:
+                        post["_fallback"] = self._original_image_fallback(
+                            url, post["id"])
                     posts.append(self._prepare_image(url, post.copy()))
+                    post.pop("_fallback", None)
                 for url in _findall_video(body):
                     url = self._original_video(url)
                     posts.append(self._prepare(url, post.copy()))
@@ -218,23 +226,35 @@ class TumblrExtractor(Extractor):
         return self.blog != post.get("reblogged_root_uuid")
 
     def _original_photo(self, url):
-        return self._update_image_token(
-            url.replace("/s2048x3072/", "/s99999x99999/", 1))
+        resized = url.replace("/s2048x3072/", "/s99999x99999/", 1)
+        return self._update_image_token(resized)
 
     def _original_inline_image(self, url):
         if self.original:
-            url, n = self._subn_orig_image("/s99999x99999/", url, 1)
+            resized, n = self._subn_orig_image("/s99999x99999/", url, 1)
             if n:
-                return self._update_image_token(url)
-        return self._sub_image(r"https://\1_1280.\2", url)
+                return self._update_image_token(resized)
+        return self._sub_image(r"https://\1_1280.\2", url), False
 
     def _original_video(self, url):
         return self._sub_video(r"https://\1.\2", url)
 
-    def _update_image_token(self, url):
+    def _update_image_token(self, resized):
         headers = {"Accept": "text/html,*/*;q=0.8"}
-        response = self.request(url, headers=headers)
-        return text.extract(response.text, '" src="', '"')[0]
+        try:
+            response = self.request(resized, headers=headers)
+        except Exception:
+            return resized, True
+        else:
+            updated = text.extract(response.text, '" src="', '"')[0]
+            return updated, (resized == updated)
+
+    def _original_image_fallback(self, url, post_id):
+        yield self._update_image_token(url)[0]
+        yield self._update_image_token(url)[0]
+        yield self._update_image_token(url)[0]
+        self.log.warning("Unable to fetch higher-resolution "
+                         "version of %s (%s)", url, post_id)
 
 
 class TumblrUserExtractor(TumblrExtractor):
